BitcoinHeader

Struct BitcoinHeader 

pub struct BitcoinHeader {
    pub hash: Hash256Digest,
    pub raw: RawHeader,
    pub height: u32,
    pub prevhash: Hash256Digest,
    pub merkle_root: Hash256Digest,
}
BitcoinHeader is a parsed Bitcoin header with height information appended. Values are LE

Fields

hash: Hash256Digest

The double-sha2 digest encoded BE.

raw: RawHeader

The 80-byte raw header.

height: u32

The height of the header

prevhash: Hash256Digest

The double-sha2 digest of the parent encoded BE.

merkle_root: Hash256Digest

The double-sha2 merkle tree root of the block transactions encoded BE.

Implementations

Source

impl BitcoinHeader

pub fn validate(&self) -> Result<(), SPVError>

Checks validity of an entire Bitcoin header

Arguments
  • self - The Bitcoin header
Errors
  • Errors if any of the Bitcoin header elements are invalid.